@@ -8,10 +8,7 @@
 """ HTML manipulation methods """
 
 import re
-import os
 import random
-import htmllib
-import formatter
 from cStringIO import StringIO
 from urlparse import urlparse
 import urllib2
@@ -33,6 +30,13 @@ def removeLinks(html):
         soup.a.replaceWith(tag)
     return  str(soup)
 
+def removeReviewHistory(html):
+
+    soup = BeautifulSoup(html)
+    for x in soup.findAll(id='review-history'):
+        x.extract()
+    return  str(soup)
+
 
 def removeImages(html):
     """ Remove all images """
@@ -212,8 +216,9 @@ def breakIntoPages(html, seperator='(h1|h2)'):
 
 
 available_manipulations = (
-    {'label' : 'removeImages', 'method' : removeImages, 'description': 'Remove images'},
-    {'label' : 'removeLinks', 'method' : removeLinks, 'description': 'Remove links'},
-    {'label' : 'addLinkList', 'method' : addLinkList, 'description': 'Add link list'},
-    {'label' : 'breakIntoPages', 'method' : breakIntoPages, 'description': 'Break into pages'},
+    {'label' : 'removeImages', 'method' : removeImages, 'description': 'Remove images', 'state' : False},
+    {'label' : 'removeLinks', 'method' : removeLinks, 'description': 'Remove links', 'state' : False},
+    {'label' : 'addLinkList', 'method' : addLinkList, 'description': 'Add link list', 'state' : False},
+    {'label' : 'breakIntoPages', 'method' : breakIntoPages, 'description': 'Break into pages', 'state' : False},
+    {'label' : 'removeReviewHistory', 'method' : removeReviewHistory, 'description': 'Remove review history', 'state' : True},
 )
